checkdata.Problems (Data problems) — amici1

# `checkdata.Problems` (Data problems)

Columns

- `<django.db.models.fields.BigAutoField: id>`

- `<django.db.models.fields.related.ForeignKey: user>`

- `<django.db.models.fields.related.ForeignKey: owner_type>`

- `<lino.modlib.gfks.fields.GenericForeignKeyIdField: owner_id>`

- `<lino.core.choicelists.ChoiceListField: checker>`

- `<django.db.models.fields.CharField: message>`

- `<lino.modlib.gfks.fields.GenericForeignKey object at 0x7fc8267decc0>`

Detail fields

- Checker (checker) : The Checker that reported this problem.

- Database object (owner) : See `<lino.modlib.gfks.fields.GenericForeignKey object at 0x7fc8267decc0>`.

- Message (message) : The message text. This is a concatenation of all messages that were yielded by the checker.

- `<Panel main_4 in lino.core.layouts.DetailLayout on lino.modlib.checkdata.models.Problems>`

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid_post) : See `<lino.core.actions.CreateRow grid_post>`.

- Create (submit_insert) : Create the record and open a detail window on it

- Detail (detail) : Open a detail window on this record.

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

- Check data (update_problem) : See `<lino.modlib.checkdata.models.UpdateProblem update_problem ('Check data')>`.

- Fix data problems (fix_problem) : See `<lino.modlib.checkdata.models.FixProblem fix_problem ('Fix data problems')>`.

Filter parameters

- `<django.db.models.fields.related.ForeignKey: user>`

- `<lino.core.choicelists.ChoiceListField: checker>`

## Filter parameters